==> kubernetes-model-flowcontrol-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/LimitResponseFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class LimitResponseFluentImpl<A extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent<A>{
  public LimitResponseFluentImpl() {
  }
  public LimitResponseFluentImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponse instance) {
    this.withQueuing(instance.getQueuing()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder queuing;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildQueuing instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration getQueuing() {
    return this.queuing!=null?this.queuing.build():null;
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration buildQueuing() {
    return this.queuing!=null?this.queuing.build():null;
  }
  public A withQueuing(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration queuing) {
    _visitables.get("queuing").remove(this.queuing);
    if (queuing!=null){ this.queuing= new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder(queuing); _visitables.get("queuing").add(this.queuing);} return (A) this;
  }
  public java.lang.Boolean hasQueuing() {
    return this.queuing != null;
  }
  public A withNewQueuing(java.lang.Integer handSize,java.lang.Integer queueLengthLimit,java.lang.Integer queues) {
    return (A)withQueuing(new QueuingConfiguration(handSize, queueLengthLimit, queues));
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> withNewQueuing() {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluentImpl.QueuingNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> withNewQueuingLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration item) {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluentImpl.QueuingNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> editQueuing() {
    return withNewQueuingLike(getQueuing());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> editOrNewQueuing() {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> editOrNewQueuingLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration item) {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitResponseFluentImpl that = (LimitResponseFluentImpl) o;
    if (queuing != null ? !queuing.equals(that.queuing) :that.queuing != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(queuing,  type,  additionalProperties,  super.hashCode());
  }
  public class QueuingNestedImpl<N> extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationFluentImpl<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<N>> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    QueuingNestedImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration item) {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder(this, item);
    }
    QueuingNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder(this);
    }
    io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder builder;
    public N and() {
      return (N) LimitResponseFluentImpl.this.withQueuing(builder.build());
    }
    public N endQueuing() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/LimitResponseFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class LimitResponseFluentImpl<A extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent<A>{
  public LimitResponseFluentImpl() {
  }
  public LimitResponseFluentImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponse instance) {
    this.withQueuing(instance.getQueuing()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder queuing;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildQueuing instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration getQueuing() {
    return this.queuing!=null?this.queuing.build():null;
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration buildQueuing() {
    return this.queuing!=null?this.queuing.build():null;
  }
  public A withQueuing(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration queuing) {
    _visitables.get("queuing").remove(this.queuing);
    if (queuing!=null){ this.queuing= new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder(queuing); _visitables.get("queuing").add(this.queuing);} return (A) this;
  }
  public java.lang.Boolean hasQueuing() {
    return this.queuing != null;
  }
  public A withNewQueuing(java.lang.Integer handSize,java.lang.Integer queueLengthLimit,java.lang.Integer queues) {
    return (A)withQueuing(new QueuingConfiguration(handSize, queueLengthLimit, queues));
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> withNewQueuing() {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluentImpl.QueuingNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> withNewQueuingLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration item) {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluentImpl.QueuingNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> editQueuing() {
    return withNewQueuingLike(getQueuing());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> editOrNewQueuing() {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<A> editOrNewQueuingLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration item) {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitResponseFluentImpl that = (LimitResponseFluentImpl) o;
    if (queuing != null ? !queuing.equals(that.queuing) :that.queuing != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(queuing,  type,  additionalProperties,  super.hashCode());
  }
  public class QueuingNestedImpl<N> extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationFluentImpl<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<N>> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitResponseFluent.QueuingNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    QueuingNestedImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfiguration item) {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder(this, item);
    }
    QueuingNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder(this);
    }
    io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.QueuingConfigurationBuilder builder;
    public N and() {
      return (N) LimitResponseFluentImpl.this.withQueuing(builder.build());
    }
    public N endQueuing() {
      return and();
    }
    
  }
  
}
